##  Roadmap Reports in SAP LeanIX Architecture and Road Map Planning
Roadmap Report gives a timeline representation of an organization's enterprise architecture elements. It visualizes the strategic initiatives, projects, and priorities that the organization plans to undertake to achieve its desired future state. It helps you monitor and manage initiatives and projects. Regular updates enable a continuous assessment of progress and identification of new opportunities to improve your organization's architecture.
For more information on Roadmap reports, including their features and guidance on working with them, see [Roadmap Report](https://help.sap.com/docs/leanix/ea/roadmap-report?locale=en-US&state=PRODUCTION&version=CLOUD).
SAP LeanIX Architecture and Road Map Planning enables you to visualize milestones of your projects in Roadmap reports, which help you keep track of your modernization plans, and ensure IT transformation is on time, scope, and budget. To learn more about Milestones, see [Milestones](https://help.sap.com/docs/leanix/ea/milestones?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to add and manage milestones and realize their value by effectively visualizing them in reports.").
